@@ -40,15 +40,10 @@
  * same handler, just pass "/" (or %NULL) for the path.) Any request
  * that does not match any handler will automatically be returned to
  * the client with a 404 (Not Found) status.
- *
- * If you want to handle the special "*" URI (eg, "OPTIONS *"), you
- * must explicitly register a handler for "*"; the default handler
- * will not be used for that case.
  * 
  * To add authentication to some or all paths, create an appropriate
  * #SoupAuthDomain (qv), and add it to the server via
- * soup_server_add_auth_domain(). (As with handlers, you must
- * explicitly add "*" to an auth domain if you want it to be covered.)
+ * soup_server_add_auth_domain.
  * 
  * Additional processing options are available via #SoupServer's
  * signals; Connect to #SoupServer::request-started to be notified
@@ -319,12 +314,6 @@ soup_server_class_init (SoupServerClass *server_class)
 			      SOUP_TYPE_CLIENT_CONTEXT);
 
 	/* properties */
-	/**
-	 * SOUP_SERVER_PORT:
-	 *
-	 * Alias for the #SoupServer:port property. (The port the
-	 * server listens on.)
-	 **/
 	g_object_class_install_property (
 		object_class, PROP_PORT,
 		g_param_spec_uint (SOUP_SERVER_PORT,
@@ -332,12 +321,6 @@ soup_server_class_init (SoupServerClass *server_class)
 				   "Port to listen on",
 				   0, 65536, 0,
 				   G_PARAM_READWRITE | G_PARAM_CONSTRUCT_ONLY));
-	/**
-	 * SOUP_SERVER_INTERFACE:
-	 *
-	 * Alias for the #SoupServer:interface property. (The address
-	 * of the network interface the server listens on.)
-	 **/
 	g_object_class_install_property (
 		object_class, PROP_INTERFACE,
 		g_param_spec_object (SOUP_SERVER_INTERFACE,
@@ -345,12 +328,6 @@ soup_server_class_init (SoupServerClass *server_class)
 				     "Address of interface to listen on",
 				     SOUP_TYPE_ADDRESS,
 				     G_PARAM_READWRITE | G_PARAM_CONSTRUCT_ONLY));
-	/**
-	 * SOUP_SERVER_SSL_CERT_FILE:
-	 *
-	 * Alias for the #SoupServer:ssl-cert-file property. (The file
-	 * containing the SSL certificate for the server.)
-	 **/
 	g_object_class_install_property (
 		object_class, PROP_SSL_CERT_FILE,
 		g_param_spec_string (SOUP_SERVER_SSL_CERT_FILE,
@@ -358,12 +335,6 @@ soup_server_class_init (SoupServerClass *server_class)
 				     "File containing server SSL certificate",
 				     NULL,
 				     G_PARAM_READWRITE | G_PARAM_CONSTRUCT_ONLY));
-	/**
-	 * SOUP_SERVER_SSL_KEY_FILE:
-	 *
-	 * Alias for the #SoupServer:ssl-key-file property. (The file
-	 * containing the SSL certificate key for the server.)
-	 **/
 	g_object_class_install_property (
 		object_class, PROP_SSL_KEY_FILE,
 		g_param_spec_string (SOUP_SERVER_SSL_KEY_FILE,
@@ -371,25 +342,12 @@ soup_server_class_init (SoupServerClass *server_class)
 				     "File containing server SSL key",
 				     NULL,
 				     G_PARAM_READWRITE | G_PARAM_CONSTRUCT_ONLY));
-	/**
-	 * SOUP_SERVER_ASYNC_CONTEXT:
-	 *
-	 * Alias for the #SoupServer:async-context property. (The
-	 * server's #GMainContext.)
-	 **/
 	g_object_class_install_property (
 		object_class, PROP_ASYNC_CONTEXT,
 		g_param_spec_pointer (SOUP_SERVER_ASYNC_CONTEXT,
 				      "Async GMainContext",
 				      "The GMainContext to dispatch async I/O in",
 				      G_PARAM_READWRITE | G_PARAM_CONSTRUCT_ONLY));
-	/**
-	 * SOUP_SERVER_RAW_PATHS:
-	 *
-	 * Alias for the #SoupServer:raw-paths property. (If %TRUE,
-	 * percent-encoding in the Request-URI path will not be
-	 * automatically decoded.)
-	 **/
 	g_object_class_install_property (
 		object_class, PROP_RAW_PATHS,
 		g_param_spec_boolean (SOUP_SERVER_RAW_PATHS,
@@ -426,11 +384,6 @@ soup_server_class_init (SoupServerClass *server_class)
 	 * "<literal>libsoup/2.3.2</literal>") to the end of the
 	 * header for you.
 	 **/
-	/**
-	 * SOUP_SERVER_SERVER_HEADER:
-	 *
-	 * Alias for the #SoupServer:server-header property, qv.
-	 **/
 	g_object_class_install_property (
 		object_class, PROP_SERVER_HEADER,
 		g_param_spec_string (SOUP_SERVER_SERVER_HEADER,
@@ -652,7 +605,7 @@ soup_server_is_https (SoupServer *server)
  * read-only; writing to it or modifiying it may cause @server to
  * malfunction.
  *
- * Return value: (transfer none): the listening socket.
+ * Return value: the listening socket.
  **/
 SoupSocket *
 soup_server_get_listener (SoupServer *server)
@@ -709,13 +662,11 @@ soup_client_context_unref (SoupClientContext *client)
 }
 
 static void
-request_finished (SoupMessage *msg, gpointer user_data)
+request_finished (SoupMessage *msg, SoupClientContext *client)
 {
-	SoupClientContext *client = user_data;
 	SoupServer *server = client->server;
 	SoupSocket *sock = client->sock;
 
-	soup_message_finished (msg);
 	g_signal_emit (server,
 		       msg->status_code == SOUP_STATUS_IO_ERROR ?
 		       signals[REQUEST_ABORTED] : signals[REQUEST_FINISHED],
@@ -746,8 +697,6 @@ soup_server_get_handler (SoupServer *server, const char *path)
 		hand = soup_path_map_lookup (priv->handlers, path);
 		if (hand)
 			return hand;
-		if (!strcmp (path, "*"))
-			return NULL;
 	}
 	return priv->default_handler;
 }
@@ -821,8 +770,6 @@ call_handler (SoupMessage *req, SoupClientContext *client)
 	SoupServerHandler *hand;
 	SoupURI *uri;
 
-	g_signal_emit (server, signals[REQUEST_READ], 0, req, client);
-
 	if (req->status_code != 0)
 		return;
 
@@ -837,7 +784,7 @@ call_handler (SoupMessage *req, SoupClientContext *client)
 		GHashTable *form_data_set;
 
 		if (uri->query)
-			form_data_set = soup_form_decode (uri->query);
+			form_data_set = soup_form_decode_urlencoded (uri->query);
 		else
 			form_data_set = NULL;
 
@@ -863,6 +810,8 @@ start_request (SoupServer *server, SoupClientContext *client)
 	msg = g_object_new (SOUP_TYPE_MESSAGE,
 			    SOUP_MESSAGE_SERVER_SIDE, TRUE,
 			    NULL);
+        soup_message_headers_set_encoding (msg->response_headers,
+                                           SOUP_ENCODING_CONTENT_LENGTH);
 	if (priv->server_header) {
 		soup_message_headers_append (msg->response_headers, "Server",
 					     priv->server_header);
@@ -870,13 +819,13 @@ start_request (SoupServer *server, SoupClientContext *client)
 
 	g_signal_connect (msg, "got_headers", G_CALLBACK (got_headers), client);
 	g_signal_connect (msg, "got_body", G_CALLBACK (call_handler), client);
+	g_signal_connect (msg, "finished", G_CALLBACK (request_finished), client);
 
 	g_signal_emit (server, signals[REQUEST_STARTED], 0,
 		       msg, client);
 
 	g_object_ref (client->sock);
-	soup_message_read_request (msg, client->sock,
-				   request_finished, client);
+	soup_message_read_request (msg, client->sock);
 }
 
 static void
@@ -990,38 +939,6 @@ soup_server_quit (SoupServer *server)
 		g_main_loop_quit (priv->loop);
 }
 
-/**
- * soup_server_disconnect:
- * @server: a #SoupServer
- *
- * Stops processing for @server and closes its socket. This implies
- * the effects of soup_server_quit(), but additionally closes the
- * listening socket.  Note that messages currently in progress will
- * continue to be handled, if the main loop associated with the
- * server is resumed or kept running.
- *
- * After calling this function, @server is no longer functional, so it
- * has nearly the same effect as destroying @server entirely. The
- * function is thus useful mainly for language bindings without
- * explicit control over object lifetime.
- **/
-void
-soup_server_disconnect (SoupServer *server)
-{
-	SoupServerPrivate *priv;
-
-	g_return_if_fail (SOUP_IS_SERVER (server));
-	priv = SOUP_SERVER_GET_PRIVATE (server);
-
-	soup_server_quit (server);
-
-	if (priv->listen_sock) {
-		soup_socket_disconnect (priv->listen_sock);
-		g_object_unref (priv->listen_sock);
-		priv->listen_sock = NULL;
-	}
-}
-
 /**
  * soup_server_get_async_context:
  * @server: a #SoupServer
@@ -1030,7 +947,7 @@ soup_server_disconnect (SoupServer *server)
  * context, so you will need to ref it yourself if you want it to
  * outlive its server.
  *
- * Return value: (transfer none): @server's #GMainContext, which may be %NULL
+ * Return value: @server's #GMainContext, which may be %NULL
  **/
 GMainContext *
 soup_server_get_async_context (SoupServer *server)
@@ -1087,8 +1004,7 @@ soup_client_context_get_type (void)
  * not get fooled when the allocator reuses the memory address of a
  * previously-destroyed socket to represent a new socket.
  *
- * Return value: (transfer none): the #SoupSocket that @client is
- * associated with.
+ * Return value: the #SoupSocket that @client is associated with.
  **/
 SoupSocket *
 soup_client_context_get_socket (SoupClientContext *client)
@@ -1105,8 +1021,8 @@ soup_client_context_get_socket (SoupClientContext *client)
  * Retrieves the #SoupAddress associated with the remote end
  * of a connection.
  *
- * Return value: (transfer none): the #SoupAddress associated with the
- * remote end of a connection.
+ * Return value: the #SoupAddress associated with the remote end of a
+ * connection.
  **/
 SoupAddress *
 soup_client_context_get_address (SoupClientContext *client)
@@ -1145,8 +1061,8 @@ soup_client_context_get_host (SoupClientContext *client)
  * authenticated, and if so returns the #SoupAuthDomain that
  * authenticated it.
  *
- * Return value: (transfer none) (allow-none): a #SoupAuthDomain, or
- * %NULL if the request was not authenticated.
+ * Return value: a #SoupAuthDomain, or %NULL if the request was not
+ * authenticated.
  **/
 SoupAuthDomain *
 soup_client_context_get_auth_domain (SoupClientContext *client)
@@ -1180,8 +1096,7 @@ soup_client_context_get_auth_user (SoupClientContext *client)
  * @server: the #SoupServer
  * @msg: the message being processed
  * @path: the path component of @msg's Request-URI
- * @query: (element-type utf8 utf8) (allow-none): the parsed query
- *         component of @msg's Request-URI
+ * @query: the parsed query component of @msg's Request-URI
  * @client: additional contextual information about the client
  * @user_data: the data passed to @soup_server_add_handler
  *
@@ -1236,7 +1151,7 @@ soup_client_context_get_auth_user (SoupClientContext *client)
 /**
  * soup_server_add_handler:
  * @server: a #SoupServer
- * @path: (allow-none): the toplevel path for the handler
+ * @path: the toplevel path for the handler
  * @callback: callback to invoke for requests under @path
  * @user_data: data for @callback
  * @destroy: destroy notifier to free @user_data
@@ -1244,12 +1159,6 @@ soup_client_context_get_auth_user (SoupClientContext *client)
  * Adds a handler to @server for requests under @path. See the
  * documentation for #SoupServerCallback for information about
  * how callbacks should behave.
- *
- * If @path is %NULL or "/", then this will be the default handler for
- * all requests that don't have a more specific handler. Note though
- * that if you want to handle requests to the special "*" URI, you
- * must explicitly register a handler for "*"; the default handler
- * will not be used for that case.
  **/
 void
 soup_server_add_handler (SoupServer            *server,
@@ -1265,13 +1174,6 @@ soup_server_add_handler (SoupServer            *server,
 	g_return_if_fail (callback != NULL);
 	priv = SOUP_SERVER_GET_PRIVATE (server);
 
-	/* "" was never documented as meaning the same this as "/",
-	 * but it effectively was. We have to special case it now or
-	 * otherwise it would match "*" too.
-	 */
-	if (path && (!*path || !strcmp (path, "/")))
-		path = NULL;
-
 	hand = g_slice_new0 (SoupServerHandler);
 	hand->path       = g_strdup (path);
 	hand->callback   = callback;
@@ -1308,7 +1210,7 @@ soup_server_remove_handler (SoupServer *server, const char *path)
 	g_return_if_fail (SOUP_IS_SERVER (server));
 	priv = SOUP_SERVER_GET_PRIVATE (server);
 
-	if (!path || !*path || !strcmp (path, "/")) {
+	if (!path) {
 		if (priv->default_handler) {
 			unregister_handler (priv->default_handler);
 			free_handler (priv->default_handler);
